@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::App::Command::dumpphases::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::App::Command::dumpphases::VERSION = '0.5.0';
+  $Dist::Zilla::App::Command::dumpphases::VERSION = '0.5.1';
 }
 
 # ABSTRACT: Dump a textual representation of each phase's parts.
@@ -52,18 +52,18 @@ sub execute {
   require Dist::Zilla::Util::RoleDB;
 
   for my $phase ( Dist::Zilla::Util::RoleDB->new()->phases ) {
-    my ( $label );
+    my ($label);
     $label = $phase->name;
     $label =~ s/\A-//msx;
     $label =~ s/([[:lower:]])([[:upper:]])/$1 $2/gmsx;
 
     my @plugins;
-    push @plugins, $zilla->plugins_with($phase->name)->flatten;
+    push @plugins, $zilla->plugins_with( $phase->name )->flatten;
     next unless @plugins;
 
     $theme->print_section_header( 'Phase: ', $label );
-    $theme->print_section_prelude( 'description: ', $phase->description );
-    $theme->print_section_prelude( 'role: ', $phase->name );
+    $theme->print_section_prelude( 'description: ',  $phase->description );
+    $theme->print_section_prelude( 'role: ',         $phase->name );
     $theme->print_section_prelude( 'phase_method: ', $phase->phase_method );
 
     for my $plugin (@plugins) {
@@ -100,7 +100,7 @@ Dist::Zilla::App::Command::dumpphases - Dump a textual representation of each ph
 
 =head1 VERSION
 
-version 0.5.0
+version 0.5.1
 
 =head1 SYNOPSIS
 
@@ -116,6 +116,57 @@ If you are using an HTML-enabled POD viewer, you should see a screenshot of this
 
 =for html <center><img src="http://kentfredric.github.io/Dist-Zilla-App-Command-dumpphases/media/example_01.png" alt="Screenshot" width="721" height="1007"/></center>
 
+=head1 TERMINOLOGY
+
+Technically speaking, this utility deals with more than just "phases", it will in fact dump all plugins used,
+and it will in the process of doing so, dump things that are part of the clearly defined "phases" that occur
+within C<Dist::Zilla>.
+
+However, if you want to be pedantic, and understand how L<< C<Dist::Zilla>|Dist::Zilla >> works, then you must understand,
+many of the things this module calls "phases" are not so much phases.
+
+At its core, C<Dist::Zilla> has an array, on which all L<< C<Plugin>s|Dist::Zilla::Role::Plugin >> are stored.
+
+A C<Plugin>, in itself, will not do very much ( at least, not unless they do instantiation-time changes like L<< C<[Bootstrap::lib]>|Dist::Zilla::Plugin::Bootstrap::lib >>
+
+There are 3 Primary kinds of plugin
+
+=over 4
+
+=item * Auxiliary Plugins
+
+Plugins which exist to augment other plugins ( For instance, L<< C<-FileFinder>'s|Dist::Zilla::Role::FileFinder >> ).
+
+C<Dist::Zilla> itself essentially ignores these, and their consumption is entirely regulated by other C<plugin>s.
+
+=item * Phase Plugins
+
+Plugins which hook into a specific and determinate phase of the C<Dist::Zilla> build/test/release cycle.
+
+These all provide primary methods, which C<Dist::Zilla> directly calls somewhere in its core code base.
+
+Good examples of Phase plugins perform L<< C<-FileGatherer>|Dist::Zilla::Role::FileGatherer >>
+
+=item * A Third Kind
+
+There's a third kind of Plugin, which is somewhere between the other two, which I presently lack a name for.
+
+Like the Phases, they provide primary methods, which are called by C<Dist::Zilla> directly, and they provide
+information for infrastructural components of the C<Dist::Zilla> development process.
+
+However, they're not strictly "phases", because exactly when they will be called ( or if they will be called at all )
+is heavily dependent on usage.
+
+For instance, L<< C<-VersionProvider>|Dist::Zilla::Role::VersionProvider >>, which is dependent on a few variables,
+and is called only when its needed, the first time its needed.
+
+Which means it could occur as early as creating C<META.json> or it could occur as late as just before it writes the distribution out to disk.
+
+=back
+
+This C<App::Command> command will indeed list all of the above, but for the sake of ease of use, the "Third kind" is informally
+under the umbrella of a "phase".
+
 =begin MetaPOD::JSON v1.1.0
 
 {
